locals {
  events_rule_arn=var.create_event_rule ? aws_cloudwatch_event_rule.glue_monitoring_rule[0].arn : ""
  events_target_arn=var.create_event_rule ? aws_cloudwatch_event_target.rule_target_sns[0].arn : ""
}
resource "aws_cloudwatch_event_rule" "glue_monitoring_rule" {
  count             = var.create_event_rule ? 1 : 0
  name        = "${var.glue_job_name}-cw-event"
  description = "Alerts on glue job state change"

  is_enabled = var.enable_event_rule
  tags       = var.tags
  event_pattern = <<PATTERN
{
  "source": [
    "aws.glue"
  ],
  "detail-type": [
    "Glue Job State Change"
  ],
  "detail": {
    "jobName": [
      "${aws_glue_job.glue_job.name}"
    ],
    "state": [
      "${var.glue_job_alert_states}"
    ]
  }
}
PATTERN
}

resource "aws_cloudwatch_event_target" "rule_target_sns" {
  count = var.create_event_rule ? 1 : 0
  rule  = aws_cloudwatch_event_rule.glue_monitoring_rule[0].name
  arn   = var.target_arn
  
  input_transformer {
    input_paths = {
      "account"   = "$.account",
      "event"     = "$",
      "jobName"   = "$.detail.jobName",
      "jobRunId"  = "$.detail.jobRunId",
      "message"   = "$.detail.message",
      "region"    = "$.region",
      "status"    = "$.detail.state",
      "timestamp" = "$.time"
    }

    input_template = <<TEMPLATE
"Glue job <jobName> state changed to <status> in account <account>, region <region> at <timestamp>."
"Message: <message>"
"JobRunId: <jobRunId>"
"Event: <event>"
TEMPLATE
  }
}

resource "aws_iam_policy" "events-policy" {
  count       = var.create_event_rule ? 1 : 0
  name        = "${var.iam_policy_prefix}-events-policy"
  path        = "/"
  description = "Glue Job EventBridge Policy"

  policy = <<EOF
{
  "Version": "2012-10-17",
  "Statement": [
    {
      "Sid": "EventBridgePermissions",
      "Effect": "Allow",
      "Action": [
          "events:Describe*",
          "events:List*",
          "events:Test*",
          "events:Create*",
          "events:EnableRule",
          "events:InvokeApiDestination",
          "events:Put*",
          "events:Update*"
      ],
      "Resource": [
          "${local.events_rule_arn}",
          "${local.events_target_arn}"
      ]
    }
  ]
}
EOF
  lifecycle {
    ignore_changes = [
      description,
    ]
  }

  tags = var.tags
}

resource "aws_iam_role_policy_attachment" "events-policy-attachment" {
  count      = var.create_event_rule ? 1 : 0
  role       = var.glue_job_role_name
  policy_arn = aws_iam_policy.events-policy[0].arn
}