#---------------------------------------------------
# Glue Job
#---------------------------------------------------
locals {
  python_version = var.glue_job_command_name == "pythonshell" ? var.python_version : null
}

resource "aws_glue_job" "glue_job" {
  name     = var.glue_job_name
  role_arn = var.glue_job_role_arn

  description            = var.glue_job_description
  default_arguments      = var.glue_job_arguments
  glue_version           = var.glue_job_version
  max_capacity           = var.glue_job_max_capacity
  max_retries            = var.glue_job_max_retries
  timeout                = var.glue_job_timeout
  worker_type            = var.glue_job_worker_type
  number_of_workers      = var.glue_job_number_of_workers
  security_configuration = aws_glue_security_configuration.glue_security_configuration.id
  connections            = var.connection_enabled ? [aws_glue_connection.glue_connection[0].name] : []

  command {
    script_location = var.glue_job_script_location
    name           = var.glue_job_command_name
    python_version = local.python_version 
  }

  execution_property {
    max_concurrent_runs = var.glue_job_max_concurrent_runs
  }

  notification_property {
    notify_delay_after = var.glue_job_delay_notification_threshold
  }

  tags = var.tags

  lifecycle {
    create_before_destroy = true
    ignore_changes        = []
  }

  depends_on = [
    aws_glue_security_configuration.glue_security_configuration
  ]
}

resource "aws_glue_trigger" "glue_job" {
  count    = length(var.schedule) > 0 ? 1 : 0
  name     = var.glue_job_name
  schedule = var.schedule
  type     = "SCHEDULED"

  actions {
    job_name = aws_glue_job.glue_job.name
  }
}

resource "aws_iam_policy" "glue-job-access-policy" {
  name        = "${var.iam_policy_prefix}-access-policy"
  path        = "/"
  description = "Glue Job Access Policy"

  policy = <<EOF
{
  "Version": "2012-10-17",
  "Statement": [
    {
      "Sid": "GlueJobAccessPermissions",
      "Effect": "Allow",
      "Action": [
          "glue:Put*",
          "glue:List*",
          "glue:Create*",
          "glue:Get*",
          "glue:Stop*",
          "glue:Start*",
          "glue:Update*",
          "glue:BatchGet*",
          "glue:BatchStop*"
      ],
      "Resource": [
          "${aws_glue_job.glue_job.arn}"
      ]
    },
    {
      "Effect": "Allow",
      "Action": [
        "glue:GetConnection"
      ],
      "Resource": ["arn:aws:glue:*:*:catalog", "arn:aws:glue:*:*:connection/*"]
    }
  ]
}
EOF
  lifecycle {
    ignore_changes = [
      description,
    ]
  }

  tags = var.tags
}

resource "aws_iam_role_policy_attachment" "glue-job-policy-attachment" {
  role       = var.glue_job_role_name
  policy_arn = aws_iam_policy.glue-job-access-policy.arn
}